REST framework JWT Auth
=======================

|build-status-image| |pypi-version|

**JSON Web Token Authentication support for Django REST Framework**

Full documentation for the project is available at `docs`_.

Overview
--------

This package provides `JSON Web Token Authentication`_ support for
`Django REST framework`_.

If you want to know more about JWT, check out the following resources:

-  DjangoCon 2014 - JSON Web Tokens `Video`_ \| `Slides`_
-  `Auth with JSON Web Tokens`_
-  `JWT.io`_

Requirements
------------

-  Python (2.7, 3.3, 3.4)
-  Django (1.6, 1.7, 1.8)
-  Django REST Framework (2.4.3, 2.4.4, 3.0.0, 3.1.0)

Installation
------------

Install using ``pip``\ ...

.. code:: bash

    $ pip install djangorestframework-jwt

Documentation & Support
-----------------------

Full documentation for the project is available at `docs`_.

You may also want to follow the `author`_ on Twitter.

.. _docs: http://getblimp.github.io/django-rest-framework-jwt
.. _JSON Web Token Authentication: http://tools.ietf.org/html/draft-ietf-oauth-json-web-token
.. _Django REST framework: http://django-rest-framework.org/
.. _Video: https://www.youtube.com/watch?v=825hodQ61bg
.. _Slides: https://speakerdeck.com/jpadilla/djangocon-json-web-tokens
.. _Auth with JSON Web Tokens: http://jpadilla.com/post/73791304724/auth-with-json-web-tokens
.. _JWT.io: http://jwt.io/
.. _author: https://twitter.com/blimp

.. |build-status-image| image:: https://secure.travis-ci.org/GetBlimp/django-rest-framework-jwt.svg?branch=master
   :target: http://travis-ci.org/GetBlimp/django-rest-framework-jwt?branch=master
.. |pypi-version| image:: https://img.shields.io/pypi/v/djangorestframework-jwt.svg
   :target: https://pypi.python.org/pypi/djangorestframework-jwt
